@@ -2,6 +2,7 @@
 
 Read: https://www.pgcon.org/2014/schedule/attachments/330_postgres-for-the-wire.pdf
 """
+import logging
 from dataclasses import dataclass
 from typing import Callable, Set, Tuple, Any
 
@@ -39,7 +40,8 @@ def move_state(context: Any, state: State) -> Tuple[Any, str]:
 
 processes = {
     Names.READ_SSL_REQUEST: State(name=Names.READ_SSL_REQUEST,
-                                  allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES, Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST, Names.CLOSE}, fn=read_ssl_request),
+                                  allowed={Names.WRITE_SSL_NO, Names.WRITE_SSL_YES,
+                                           Names.WRITE_PLAIN_TEXT_PASSWORD_REQUEST, Names.CLOSE}, fn=read_ssl_request),
     Names.WRITE_SSL_NO: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
                               fn=write_ssl_resp_no),
     Names.WRITE_SSL_YES: State(name=Names.READ_SSL_REQUEST, allowed={Names.READ_STARTUP_MESSAGE, Names.CLOSE},
@@ -131,20 +133,26 @@ processes = {
 
 def run_states(context, state_name):
     while state_name != Names.CLOSE:
-        print(f"Running state {state_name}")
-        state = processes.get(state_name)
+        context, state_name = run_state(context, state_name)
 
-        if hasattr(context.output, 'flush'):
-            try:
-                context.output.flush()
-            except Exception as e:
-                log_exception(e)
+    logging.info("End run states")
 
-        context, state_name = move_state(context, state)
+    return context, state_name
 
-        if not state_name:
-            state_name = Names.CLOSE
 
-    print("End run states")
+def run_state(context, state_name):
+    logging.info(f"Running state {state_name}")
+    state = processes.get(state_name)
+
+    if hasattr(context.output, 'flush'):
+        try:
+            context.output.flush()
+        except Exception as e:
+            log_exception(e)
+
+    context, state_name = move_state(context, state)
+
+    if not state_name:
+        state_name = Names.CLOSE
 
     return context, state_name
